==> dscript_exec-1.0.0.tar.gz: lib/exec/cmd_composite.dart <==
part of dscript.exec;

class CompositeCmd extends Object with RunnerMixin implements Command {
  final Command first;

  final List<Op> ops;

  CompositeCmd(this.first, [this.ops = const []]);

  String get executable => first.executable;

  List<String> get args => first.args;

  Command operator |(/* Command | InlineFunc | InlineStringFunc */ cmd) {
    if (cmd is Command) return pipe(cmd);
    if (cmd is InlineFunc) return pipeInline(cmd);
    if (cmd is InlineStringFunc) return pipeInlineString(cmd);
    throw new UnsupportedError(
        'Pipe operation not supported for provided command!');
  }

  Command operator >(
      /* File | Uri | StreamConsumer<List<int>> | StreamConsumer<String> | StringBuffer | List<int> */ file) {
    ops.add(new OutputRedirect(file));
    return this;
  }

  Command operator <(
      /* File | Uri | List<int> | Stream<List<int>> | String */ file) {
    ops.add(new InputRedirect(file));
    return this;
  }

  Command pipe(Command cmd) {
    ops.add(new Pipe(cmd));
    return this;
  }

  Command pipeInline(InlineFunc cmd) {
    ops.add(new InlinePipe(cmd));
    return this;
  }

  Command pipeInlineString(InlineStringFunc cmd) {
    ops.add(new InlineStringPipe(cmd));
    return this;
  }

  Command pipeInlineLine(InlineStringFunc cmd) {
    ops.add(new InlineLinePipe(cmd));
    return this;
  }

  Future<Process> run({FutureOr onFinish(Process process)}) async {
    Process last = await first.run();
    for (Op sc in ops) {
      last = await sc.runWith(last);
    }
    if (onFinish != null) await onFinish(last);
    return last;
  }
}

==> dscript_exec-2.0.2.tar.gz: lib/exec/cmd_composite.dart <==
part of dscript.exec;

class CompositeCmd extends Object with RunnerMixin implements Command {
  final Command first;

  final List<Op> ops;

  CompositeCmd(this.first, [this.ops = const []]);

  @override
  String get executable => first.executable;

  @override
  List<String> get args => first.args;

  @override
  Command operator |(/* Command | InlineFunc | InlineStringFunc */ cmd) {
    if (cmd is Command) return pipe(cmd);
    if (cmd is InlineFunc) return pipeInline(cmd);
    if (cmd is InlineStringFunc) return pipeInlineString(cmd);
    throw UnsupportedError(
        'Pipe operation not supported for provided command!');
  }

  @override
  Command operator >(
      /* File | Uri | StreamConsumer<List<int>> | StreamConsumer<String> | StringBuffer | List<int> */
      file) {
    ops.add(OutputRedirect(file));
    return this;
  }

  @override
  Command operator <(
      /* File | Uri | List<int> | Stream<List<int>> | String */
      file) {
    ops.add(InputRedirect(file));
    return this;
  }

  @override
  Command pipe(Command cmd) {
    ops.add(Pipe(cmd));
    return this;
  }

  @override
  Command pipeInline(InlineFunc cmd) {
    ops.add(InlinePipe(cmd));
    return this;
  }

  @override
  Command pipeInlineString(InlineStringFunc cmd) {
    ops.add(InlineStringPipe(cmd));
    return this;
  }

  @override
  Command pipeInlineLine(InlineStringFunc cmd) {
    ops.add(InlineLinePipe(cmd));
    return this;
  }

  @override
  Future<Process> run({FutureOr Function(Process process) onFinish}) async {
    Process last = await first.run();
    for (Op sc in ops) {
      last = await sc.runWith(last);
    }
    if (onFinish != null) await onFinish(last);
    return last;
  }
}
